==> job-scheduler_0.22.7.tar.xz: 64/translations/job-scheduler_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>CronModel</name>
    <message>
        <location filename="../CronModel.cpp" line="114"/>
        <source>Time</source>
        <translation>Aika</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="116"/>
        <source>User</source>
        <translation>Käyttäjä</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="118"/>
        <source>Command</source>
        <translation>Käsky</translation>
    </message>
</context>
<context>
    <name>ExecuteList</name>
    <message>
        <location filename="../ExecuteList.cpp" line="36"/>
        <source>Max Item</source>
        <translation>Kohde enintään</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="38"/>
        <source>Max Date</source>
        <translation>Päivä enintään</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="40"/>
        <source>Select</source>
        <translation>Valitse</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="44"/>
        <source>&amp;Update</source>
        <translation>&amp;Päivitä</translation>
    </message>
</context>
<context>
    <name>ExecuteModel</name>
    <message>
        <location filename="../ExecuteModel.cpp" line="63"/>
        <source>Execute Time</source>
        <translation>Suoritusaika</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="65"/>
        <source>Time</source>
        <translation>Aika</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="67"/>
        <source>User</source>
        <translation>Käyttäjä</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="69"/>
        <source>Command</source>
        <translation>Käsky</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="49"/>
        <source>&amp;Command</source>
        <translation>&amp;Komento</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="51"/>
        <source>&amp;Variables</source>
        <translation>&amp;Muuttujat</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="53"/>
        <source>&amp;Job List</source>
        <translation>&amp;Työlista</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="94"/>
        <location filename="../MainWindow.cpp" line="191"/>
        <location filename="../MainWindow.cpp" line="242"/>
        <location filename="../MainWindow.cpp" line="263"/>
        <location filename="../MainWindow.cpp" line="333"/>
        <source>Job Scheduler</source>
        <translation>Työn vuorontaja</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="118"/>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="119"/>
        <source>File</source>
        <translation>Tiedosto</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="122"/>
        <source>&amp;New Item</source>
        <translation>&amp;Uusi kohde</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="123"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="126"/>
        <source>&amp;Reload</source>
        <translation>&amp;Päivitä</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="127"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="129"/>
        <source>&amp;Save</source>
        <translation>&amp;Tallenna</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="130"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="133"/>
        <source>Start as &amp;Root</source>
        <translation>Käynnistä &amp;Root</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="135"/>
        <source>Start as &amp;Regular user</source>
        <translation>Käynnistä &amp;Normaali käyttäjä</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="136"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="140"/>
        <source>E&amp;xit</source>
        <translation>P&amp;oistu</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="141"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="148"/>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="149"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="151"/>
        <source>Cu&amp;t</source>
        <translation>Le&amp;ikkaa</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="152"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="154"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopioi</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="155"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="157"/>
        <source>&amp;Paste</source>
        <translation>&amp;Liitä</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="158"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="161"/>
        <source>&amp;Delete</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="162"/>
        <source>Del</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="173"/>
        <location filename="../MainWindow.cpp" line="176"/>
        <source>&amp;Help</source>
        <translation>&amp;Ohje</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="175"/>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="243"/>
        <source>Not saved since last change.
Are you OK to reload?</source>
        <translation>Ei tallennusta viimeisimmän muutoksen jälkeen.
Haluatko ladata uudelleen?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="334"/>
        <source>Not saved since last change.
Are you OK to exit?</source>
        <translation>Ei tallennusta viimeisimmän muutoksen jälkeen.
Haluatko poistua?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="346"/>
        <source>About Job Scheduler</source>
        <translation>TIetoja työn vuorontajasta</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="347"/>
        <source>&lt;b&gt;Job Scheduler&lt;/b&gt;</source>
        <translation>&lt;b&gt;Työn vuorontaja&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="347"/>
        <source>Version: %1</source>
        <translation>Versio: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="348"/>
        <source>Job Scheduler is based upon qroneko 0.5.4, released in 2005 by korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</source>
        <translation>Job Scheduler pohjautuu qroneko 0.5.4, julkaistu vuonna 2005 tekijältä korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="349"/>
        <source>Original project page: %1</source>
        <translation>Alkuperäinen projektin sivu: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="350"/>
        <source>MX project page: %1</source>
        <translation>MX projekin sivu: %1</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../SaveDialog.cpp" line="19"/>
        <source>Save New Schedule</source>
        <translation>Tallenna uusi vuoro</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="32"/>
        <source>User:</source>
        <translation>Käyttäjä:</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="40"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="41"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Peru</translation>
    </message>
</context>
<context>
    <name>TCommandEdit</name>
    <message>
        <location filename="../TCommandEdit.cpp" line="40"/>
        <source>User:</source>
        <translation>Käyttäjä:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="48"/>
        <source>Time:</source>
        <translation>Aika:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="51"/>
        <source>Time String E&amp;ditor</source>
        <translation>Ajan esitysmuodon m&amp;uokkain</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="55"/>
        <source>Command:</source>
        <translation>Komento:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="61"/>
        <source>Comment:</source>
        <translation>Kommentti:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="64"/>
        <source>Job Schedule:</source>
        <translation>Työn vuoro:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="126"/>
        <source>Time Format Error</source>
        <translation>Virhe aikamuodossa</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="143"/>
        <source>Today</source>
        <translation>Tänään</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="145"/>
        <source>Tomorrow</source>
        <translation>Huomenna</translation>
    </message>
</context>
<context>
    <name>TimeDialog</name>
    <message>
        <location filename="../TimeDialog.cpp" line="75"/>
        <source>time</source>
        <translation>aika</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="80"/>
        <source>Minute</source>
        <translation>Minuutti</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="92"/>
        <source>Hour</source>
        <translation>Tunti</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="98"/>
        <source>AM </source>
        <translation>Ennen keskipäivää</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="104"/>
        <source>PM </source>
        <translation>Keskipäivän jälkeen</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="111"/>
        <source>Day</source>
        <translation>Päivä</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="126"/>
        <source>Month</source>
        <translation>Kuukausi</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="140"/>
        <source>Week</source>
        <translation>Viikko</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="152"/>
        <source>Simple</source>
        <translation>Yksinkertainen</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="166"/>
        <source>Enable Literal</source>
        <translation>Ota käyttöön vakiomuotoilu</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="168"/>
        <source>&amp;Reset</source>
        <translation>&amp;Nollaa</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="169"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Peru</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="170"/>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
</context>
<context>
    <name>VariableEdit</name>
    <message>
        <location filename="../VariableEdit.cpp" line="46"/>
        <source>Variables</source>
        <translation>Muuttujat</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="51"/>
        <source>Mail:</source>
        <translation>Sähköposti:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="52"/>
        <source>Don&apos;t send</source>
        <translation>Älä lähetä</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="53"/>
        <source>Send</source>
        <translation>Lähetä</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="54"/>
        <source>To</source>
        <translation>Vastaanottaja</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="66"/>
        <source>&amp;New</source>
        <translation>&amp;Uusi</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="69"/>
        <source>&amp;Delete</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="77"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="82"/>
        <source>Value:</source>
        <translation>Arvo:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="85"/>
        <source>Comment:</source>
        <translation>Kommentti:</translation>
    </message>
</context>
<context>
    <name>VariableModel</name>
    <message>
        <location filename="../VariableModel.cpp" line="37"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../VariableModel.cpp" line="39"/>
        <source>Value</source>
        <translation>Arvo</translation>
    </message>
</context>
</TS>

==> job-scheduler_0.22.10.01.tar.xz: 64/translations/job-scheduler_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>CronModel</name>
    <message>
        <location filename="../CronModel.cpp" line="114"/>
        <source>Time</source>
        <translation>Aika</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="116"/>
        <source>User</source>
        <translation>Käyttäjä</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="118"/>
        <source>Command</source>
        <translation>Käsky</translation>
    </message>
</context>
<context>
    <name>ExecuteList</name>
    <message>
        <location filename="../ExecuteList.cpp" line="36"/>
        <source>Max Item</source>
        <translation>Kohde enintään</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="38"/>
        <source>Max Date</source>
        <translation>Päivä enintään</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="40"/>
        <source>Select</source>
        <translation>Valitse</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="44"/>
        <source>&amp;Update</source>
        <translation>&amp;Päivitä</translation>
    </message>
</context>
<context>
    <name>ExecuteModel</name>
    <message>
        <location filename="../ExecuteModel.cpp" line="63"/>
        <source>Execute Time</source>
        <translation>Suoritusaika</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="65"/>
        <source>Time</source>
        <translation>Aika</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="67"/>
        <source>User</source>
        <translation>Käyttäjä</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="69"/>
        <source>Command</source>
        <translation>Käsky</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="50"/>
        <source>&amp;Command</source>
        <translation>&amp;Komento</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="52"/>
        <source>&amp;Variables</source>
        <translation>&amp;Muuttujat</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="54"/>
        <source>&amp;Job List</source>
        <translation>&amp;Työlista</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="95"/>
        <location filename="../MainWindow.cpp" line="188"/>
        <location filename="../MainWindow.cpp" line="233"/>
        <location filename="../MainWindow.cpp" line="254"/>
        <location filename="../MainWindow.cpp" line="324"/>
        <source>Job Scheduler</source>
        <translation>Työn vuorontaja</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="119"/>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="120"/>
        <source>File</source>
        <translation>Tiedosto</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="123"/>
        <source>&amp;New Item</source>
        <translation>&amp;Uusi kohde</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="124"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="127"/>
        <source>&amp;Reload</source>
        <translation>&amp;Päivitä</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="128"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="130"/>
        <source>&amp;Save</source>
        <translation>&amp;Tallenna</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="131"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="134"/>
        <source>Start as &amp;Root</source>
        <translation>Käynnistä &amp;Root</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="136"/>
        <source>Start as &amp;Regular user</source>
        <translation>Käynnistä &amp;Normaali käyttäjä</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="137"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="141"/>
        <source>E&amp;xit</source>
        <translation>P&amp;oistu</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="142"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="149"/>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="150"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="152"/>
        <source>Cu&amp;t</source>
        <translation>Le&amp;ikkaa</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="153"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="155"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopioi</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="156"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="158"/>
        <source>&amp;Paste</source>
        <translation>&amp;Liitä</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="159"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="162"/>
        <source>&amp;Delete</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="163"/>
        <source>Del</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="174"/>
        <location filename="../MainWindow.cpp" line="177"/>
        <source>&amp;Help</source>
        <translation>&amp;Ohje</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="176"/>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="234"/>
        <source>Not saved since last change.
Are you OK to reload?</source>
        <translation>Ei tallennusta viimeisimmän muutoksen jälkeen.
Haluatko ladata uudelleen?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="325"/>
        <source>Not saved since last change.
Are you OK to exit?</source>
        <translation>Ei tallennusta viimeisimmän muutoksen jälkeen.
Haluatko poistua?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="338"/>
        <source>About Job Scheduler</source>
        <translation>TIetoja työn vuorontajasta</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="338"/>
        <source>&lt;b&gt;Job Scheduler&lt;/b&gt;</source>
        <translation>&lt;b&gt;Työn vuorontaja&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="338"/>
        <source>Version: %1</source>
        <translation>Versio: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="339"/>
        <source>Job Scheduler is based upon qroneko 0.5.4, released in 2005 by korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</source>
        <translation>Job Scheduler pohjautuu qroneko 0.5.4, julkaistu vuonna 2005 tekijältä korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="340"/>
        <source>Original project page: %1</source>
        <translation>Alkuperäinen projektin sivu: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="341"/>
        <source>MX project page: %1</source>
        <translation>MX projekin sivu: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="343"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="50"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../SaveDialog.cpp" line="19"/>
        <source>Save New Schedule</source>
        <translation>Tallenna uusi vuoro</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="32"/>
        <source>User:</source>
        <translation>Käyttäjä:</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="40"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="41"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Peru</translation>
    </message>
</context>
<context>
    <name>TCommandEdit</name>
    <message>
        <location filename="../TCommandEdit.cpp" line="40"/>
        <source>User:</source>
        <translation>Käyttäjä:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="48"/>
        <source>Time:</source>
        <translation>Aika:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="51"/>
        <source>Time String E&amp;ditor</source>
        <translation>Ajan esitysmuodon m&amp;uokkain</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="55"/>
        <source>Command:</source>
        <translation>Komento:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="61"/>
        <source>Comment:</source>
        <translation>Kommentti:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="64"/>
        <source>Job Schedule:</source>
        <translation>Työn vuoro:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="126"/>
        <source>Time Format Error</source>
        <translation>Virhe aikamuodossa</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="143"/>
        <source>Today</source>
        <translation>Tänään</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="145"/>
        <source>Tomorrow</source>
        <translation>Huomenna</translation>
    </message>
</context>
<context>
    <name>TimeDialog</name>
    <message>
        <location filename="../TimeDialog.cpp" line="75"/>
        <source>time</source>
        <translation>aika</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="80"/>
        <source>Minute</source>
        <translation>Minuutti</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="92"/>
        <source>Hour</source>
        <translation>Tunti</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="98"/>
        <source>AM </source>
        <translation>Ennen keskipäivää</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="104"/>
        <source>PM </source>
        <translation>Keskipäivän jälkeen</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="111"/>
        <source>Day</source>
        <translation>Päivä</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="126"/>
        <source>Month</source>
        <translation>Kuukausi</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="140"/>
        <source>Week</source>
        <translation>Viikko</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="152"/>
        <source>Simple</source>
        <translation>Yksinkertainen</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="166"/>
        <source>Enable Literal</source>
        <translation>Ota käyttöön vakiomuotoilu</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="168"/>
        <source>&amp;Reset</source>
        <translation>&amp;Nollaa</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="169"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Peru</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="170"/>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
</context>
<context>
    <name>VariableEdit</name>
    <message>
        <location filename="../VariableEdit.cpp" line="46"/>
        <source>Variables</source>
        <translation>Muuttujat</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="51"/>
        <source>Mail:</source>
        <translation>Sähköposti:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="52"/>
        <source>Don&apos;t send</source>
        <translation>Älä lähetä</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="53"/>
        <source>Send</source>
        <translation>Lähetä</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="54"/>
        <source>To</source>
        <translation>Vastaanottaja</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="66"/>
        <source>&amp;New</source>
        <translation>&amp;Uusi</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="69"/>
        <source>&amp;Delete</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="77"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="82"/>
        <source>Value:</source>
        <translation>Arvo:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="85"/>
        <source>Comment:</source>
        <translation>Kommentti:</translation>
    </message>
</context>
<context>
    <name>VariableModel</name>
    <message>
        <location filename="../VariableModel.cpp" line="37"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location filename="../VariableModel.cpp" line="39"/>
        <source>Value</source>
        <translation>Arvo</translation>
    </message>
</context>
</TS>
